@@ -54,6 +54,9 @@ bad_500_request = mock.Mock(return_value=(bad_500_response))
 connection_error_request = mock.Mock(
     side_effect=requests.exceptions.ConnectionError)
 
+timeout_error_request = mock.Mock(
+    side_effect=requests.exceptions.Timeout)
+
 
 def get_client(retries=0):
     cl = client.HTTPClient("username", "password",
@@ -68,6 +71,14 @@ def get_authed_client(retries=0):
     return cl
 
 
+def get_authed_bypass_url(retries=0):
+    cl = client.HTTPClient("username", "password",
+                           "project_id", "auth_test",
+                           bypass_url="volume/v100/", retries=retries)
+    cl.auth_token = "token"
+    return cl
+
+
 class ClientTest(utils.TestCase):
 
     def test_get(self):
@@ -198,6 +209,10 @@ class ClientTest(utils.TestCase):
         test_get_call()
         self.assertEqual([], self.requests)
 
+    def test_get_no_auth_url(self):
+        client.HTTPClient("username", "password",
+                          "project_id", retries=0)
+
     def test_post(self):
         cl = get_authed_client()
 
@@ -220,6 +235,11 @@ class ClientTest(utils.TestCase):
 
         test_post_call()
 
+    def test_bypass_url(self):
+        cl = get_authed_bypass_url()
+        self.assertEqual("volume/v100", cl.bypass_url)
+        self.assertEqual("volume/v100", cl.management_url)
+
     def test_auth_failure(self):
         cl = get_client()
 
@@ -241,3 +261,20 @@ class ClientTest(utils.TestCase):
             self.assertRaises(NotImplementedError, cl.authenticate)
 
         test_auth_call()
+
+    def test_get_retry_timeout_error(self):
+        cl = get_authed_client(retries=1)
+
+        self.requests = [timeout_error_request, mock_request]
+
+        def request(*args, **kwargs):
+            next_request = self.requests.pop(0)
+            return next_request(*args, **kwargs)
+
+        @mock.patch.object(requests, "request", request)
+        @mock.patch('time.time', mock.Mock(return_value=1234))
+        def test_get_call():
+            resp, body = cl.get("/hi")
+
+        test_get_call()
+        self.assertEqual(self.requests, [])
