@@ -14,6 +14,7 @@
 #    under the License.
 
 import fixtures
+import mock
 from requests_mock.contrib import fixture as requests_mock_fixture
 
 from cinderclient import client
@@ -54,9 +55,9 @@ class ShellTest(utils.TestCase):
             text=keystone_client.keystone_request_callback)
 
     def tearDown(self):
-        # For some method like test_image_meta_bad_action we are
+        # For some methods like test_image_meta_bad_action we are
         # testing a SystemExit to be thrown and object self.shell has
-        # no time to get instantatiated which is OK in this case, so
+        # no time to get instantiated, which is OK in this case, so
         # we make sure the method is there before launching it.
         if hasattr(self.shell, 'cs'):
             self.shell.cs.clear_callstack()
@@ -103,9 +104,42 @@ class ShellTest(utils.TestCase):
         self.run_command('list --limit=10')
         self.assert_called('GET', '/volumes/detail?limit=10')
 
-    def test_list_sort(self):
-        self.run_command('list --sort_key=name --sort_dir=asc')
-        self.assert_called('GET', '/volumes/detail?sort_dir=asc&sort_key=name')
+    def test_list_sort_valid(self):
+        self.run_command('list --sort_key=id --sort_dir=asc')
+        self.assert_called('GET', '/volumes/detail?sort_dir=asc&sort_key=id')
+
+    def test_list_sort_name(self):
+        # Client 'name' key is mapped to 'display_name'
+        self.run_command('list --sort_key=name')
+        self.assert_called('GET', '/volumes/detail?sort_key=display_name')
+
+    def test_list_sort_key_invalid(self):
+        self.assertRaises(ValueError,
+                          self.run_command,
+                          'list --sort_key=foo --sort_dir=asc')
+
+    def test_list_sort_dir_invalid(self):
+        self.assertRaises(ValueError,
+                          self.run_command,
+                          'list --sort_key=id --sort_dir=foo')
+
+    def test_list_reorder_with_sort(self):
+        # sortby_index is None if there is sort information
+        for cmd in ['list --sort_key=name',
+                    'list --sort_dir=asc',
+                    'list --sort_key=name --sort_dir=asc']:
+            with mock.patch('cinderclient.utils.print_list') as mock_print:
+                self.run_command(cmd)
+                mock_print.assert_called_once_with(
+                    mock.ANY, mock.ANY, sortby_index=None)
+
+    def test_list_reorder_without_sort(self):
+        # sortby_index is 0 without sort information
+        for cmd in ['list', 'list --all-tenants']:
+            with mock.patch('cinderclient.utils.print_list') as mock_print:
+                self.run_command(cmd)
+                mock_print.assert_called_once_with(
+                    mock.ANY, mock.ANY, sortby_index=0)
 
     def test_list_availability_zone(self):
         self.run_command('availability-zone-list')
@@ -298,6 +332,55 @@ class ShellTest(utils.TestCase):
         self.assert_called_anytime('POST', '/snapshots/5678/action',
                                    body=expected)
 
+    def test_type_list(self):
+        self.run_command('type-list')
+        self.assert_called_anytime('GET', '/types')
+
+    def test_type_list_all(self):
+        self.run_command('type-list --all')
+        self.assert_called_anytime('GET', '/types?is_public=None')
+
+    def test_type_create(self):
+        self.run_command('type-create test-type-1')
+        self.assert_called('POST', '/types')
+
+    def test_type_create_public(self):
+        expected = {'volume_type': {'name': 'test-type-1',
+                                    'description': 'test_type-1-desc',
+                                    'os-volume-type-access:is_public': True}}
+        self.run_command('type-create test-type-1 '
+                         '--description=test_type-1-desc '
+                         '--is-public=True')
+        self.assert_called('POST', '/types', body=expected)
+
+    def test_type_create_private(self):
+        expected = {'volume_type': {'name': 'test-type-3',
+                                    'description': 'test_type-3-desc',
+                                    'os-volume-type-access:is_public': False}}
+        self.run_command('type-create test-type-3 '
+                         '--description=test_type-3-desc '
+                         '--is-public=False')
+        self.assert_called('POST', '/types', body=expected)
+
+    def test_type_access_list(self):
+        self.run_command('type-access-list --volume-type 3')
+        self.assert_called('GET', '/types/3/os-volume-type-access')
+
+    def test_type_access_add_project(self):
+        expected = {'addProjectAccess': {'project': '101'}}
+        self.run_command('type-access-add --volume-type 3 --project-id 101')
+        self.assert_called_anytime('GET', '/types/3')
+        self.assert_called('POST', '/types/3/action',
+                           body=expected)
+
+    def test_type_access_remove_project(self):
+        expected = {'removeProjectAccess': {'project': '101'}}
+        self.run_command('type-access-remove '
+                         '--volume-type 3 --project-id 101')
+        self.assert_called_anytime('GET', '/types/3')
+        self.assert_called('POST', '/types/3/action',
+                           body=expected)
+
     def test_encryption_type_list(self):
         """
         Test encryption-type-list shell command.
@@ -445,12 +528,12 @@ class ShellTest(utils.TestCase):
         self.assert_called('DELETE', '/snapshots/5678')
 
     def test_volume_manage(self):
-        self.run_command('manage host1 key1=val1 key2=val2 '
+        self.run_command('manage host1 some_fake_name '
                          '--name foo --description bar '
                          '--volume-type baz --availability-zone az '
                          '--metadata k1=v1 k2=v2')
         expected = {'volume': {'host': 'host1',
-                               'ref': {'key1': 'val1', 'key2': 'val2'},
+                               'ref': {'source-name': 'some_fake_name'},
                                'name': 'foo',
                                'description': 'bar',
                                'volume_type': 'baz',
@@ -466,12 +549,12 @@ class ShellTest(utils.TestCase):
         If this flag is specified, then the resulting POST should contain
         bootable: True.
         """
-        self.run_command('manage host1 key1=val1 key2=val2 '
+        self.run_command('manage host1 some_fake_name '
                          '--name foo --description bar --bootable '
                          '--volume-type baz --availability-zone az '
                          '--metadata k1=v1 k2=v2')
         expected = {'volume': {'host': 'host1',
-                               'ref': {'key1': 'val1', 'key2': 'val2'},
+                               'ref': {'source-name': 'some_fake_name'},
                                'name': 'foo',
                                'description': 'bar',
                                'volume_type': 'baz',
@@ -487,14 +570,12 @@ class ShellTest(utils.TestCase):
         Checks that the --source-name option correctly updates the
         ref structure that is passed in the HTTP POST
         """
-        self.run_command('manage host1 key1=val1 key2=val2 '
-                         '--source-name VolName '
+        self.run_command('manage host1 VolName '
                          '--name foo --description bar '
                          '--volume-type baz --availability-zone az '
                          '--metadata k1=v1 k2=v2')
         expected = {'volume': {'host': 'host1',
-                               'ref': {'source-name': 'VolName',
-                                       'key1': 'val1', 'key2': 'val2'},
+                               'ref': {'source-name': 'VolName'},
                                'name': 'foo',
                                'description': 'bar',
                                'volume_type': 'baz',
@@ -510,14 +591,13 @@ class ShellTest(utils.TestCase):
         Checks that the --source-id option correctly updates the
         ref structure that is passed in the HTTP POST
         """
-        self.run_command('manage host1 key1=val1 key2=val2 '
-                         '--source-id 1234 '
+        self.run_command('manage host1 1234 '
+                         '--id-type source-id '
                          '--name foo --description bar '
                          '--volume-type baz --availability-zone az '
                          '--metadata k1=v1 k2=v2')
         expected = {'volume': {'host': 'host1',
-                               'ref': {'source-id': '1234',
-                                       'key1': 'val1', 'key2': 'val2'},
+                               'ref': {'source-id': '1234'},
                                'name': 'foo',
                                'description': 'bar',
                                'volume_type': 'baz',
@@ -540,3 +620,24 @@ class ShellTest(utils.TestCase):
         self.run_command('replication-reenable 1234')
         self.assert_called('POST', '/volumes/1234/action',
                            body={'os-reenable-replica': None})
+
+    def test_create_snapshot_from_volume_with_metadata(self):
+        """
+        Tests create snapshot with --metadata parameter.
+
+        Checks metadata params are set during create snapshot
+        when metadata is passed
+        """
+        expected = {'snapshot': {'volume_id': 1234,
+                                 'metadata': {'k1': 'v1',
+                                              'k2': 'v2'}}}
+        self.run_command('snapshot-create 1234 --metadata k1=v1 k2=v2')
+        self.assert_called_anytime('POST', '/snapshots', partial_body=expected)
+
+    def test_get_pools(self):
+        self.run_command('get-pools')
+        self.assert_called('GET', '/scheduler-stats/get_pools')
+
+    def test_get_pools_detail(self):
+        self.run_command('get-pools --detail')
+        self.assert_called('GET', '/scheduler-stats/get_pools?detail=True')
